@@ -1,9 +1,9 @@
-__version__ = "0.7.4"
+__version__ = "0.8.0"
 __author__ = "PyTorchLightning et al."
 __author_email__ = "name@pytorchlightning.ai"
 __license__ = "Apache-2.0"
 __copyright__ = f"Copyright (c) 2020-2022, {__author__}."
-__homepage__ = "https://github.com/PyTorchLightning/lightning-flash"
+__homepage__ = "https://github.com/Lightning-AI/lightning-flash"
 __docs_url__ = "https://lightning-flash.readthedocs.io/en/stable/"
 __docs__ = "Your PyTorch AI Factory - Flash enables you to easily configure and run complex AI recipes."
 __long_doc__ = """
