@@ -44,6 +44,7 @@ tasks = [
     "flash.graph.classification",
     "flash.image.classification",
     "flash.image.detection",
+    "flash.image.face_detection",
     "flash.image.instance_segmentation",
     "flash.image.keypoint_detection",
     "flash.image.segmentation",
@@ -51,6 +52,7 @@ tasks = [
     "flash.pointcloud.detection",
     "flash.pointcloud.segmentation",
     "flash.tabular.classification",
+    "flash.tabular.regression",
     "flash.tabular.forecasting",
     "flash.text.classification",
     "flash.text.question_answering",
