@@ -15,7 +15,7 @@ from typing import Any, Callable, Collection, Dict, List, Optional, Sequence, Ty
 
 import numpy as np
 import pandas as pd
-import torch
+from torch import Tensor
 
 from flash.audio.classification.input import (
     AudioClassificationCSVInput,
@@ -32,7 +32,6 @@ from flash.core.data.io.input import Input
 from flash.core.data.io.input_transform import INPUT_TRANSFORM_TYPE
 from flash.core.data.utilities.classification import TargetFormatter
 from flash.core.data.utilities.paths import PATH_TYPE
-from flash.core.registry import FlashRegistry
 from flash.core.utilities.imports import _AUDIO_TESTING
 from flash.core.utilities.stages import RunningStage
 from flash.image.classification.data import MatplotlibVisualization
@@ -47,7 +46,6 @@ class AudioClassificationData(DataModule):
     classmethods for loading data for audio classification."""
 
     input_transform_cls = AudioClassificationInputTransform
-    input_transforms_registry = FlashRegistry("input_transforms")
 
     @classmethod
     def from_files(
@@ -59,20 +57,22 @@ class AudioClassificationData(DataModule):
         test_files: Optional[Sequence[str]] = None,
         test_targets: Optional[Sequence[Any]] = None,
         predict_files: Optional[Sequence[str]] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        target_formatter: Optional[TargetFormatter] = None,
+        sampling_rate: int = 16000,
+        n_fft: int = 400,
         input_cls: Type[Input] = AudioClassificationFilesInput,
+        transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
         transform_kwargs: Optional[Dict] = None,
+        target_formatter: Optional[TargetFormatter] = None,
         **data_module_kwargs: Any,
     ) -> "AudioClassificationData":
         """Load the :class:`~flash.audio.classification.data.AudioClassificationData` from lists of files and
         corresponding lists of targets.
 
-        The supported file extensions are: ``.jpg``, ``.jpeg``, ``.png``, ``.ppm``, ``.bmp``, ``.pgm``, ``.tif``,
-        ``.tiff``, ``.webp``, and ``.npy``.
+        The supported file extensions for precomputed spectrograms are: ``.jpg``, ``.jpeg``, ``.png``, ``.ppm``,
+        ``.bmp``, ``.pgm``, ``.tif``, ``.tiff``, ``.webp``, and ``.npy``.
+        The supported file extensions for raw audio (where spectrograms will be computed automatically) are: ``.aiff``,
+        ``.au``, ``.avr``, ``.caf``, ``.flac``, ``.mat``, ``.mat4``, ``.mat5``, ``.mpc2k``, ``.ogg``, ``.paf``,
+        ``.pvf``, ``.rf64``, ``.ircam``, ``.voc``, ``.w64``, ``.wav``, ``.nist``, and ``.wavex``.
         The targets can be in any of our
         :ref:`supported classification target formats <formatting_classification_targets>`.
         To learn how to customize the transforms applied for each stage, read our
@@ -86,14 +86,12 @@ class AudioClassificationData(DataModule):
             test_files: The list of spectrogram image files to use when testing.
             test_targets: The list of targets to use when testing.
             predict_files: The list of spectrogram image files to use when predicting.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-                predicting.
+            sampling_rate: Sampling rate to use when loading raw audio files.
+            n_fft: The size of the FFT to use when creating spectrograms from raw audio.
             target_formatter: Optionally provide a :class:`~flash.core.data.utilities.classification.TargetFormatter` to
                 control how targets are handled. See :ref:`formatting_classification_targets` for more details.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
                 :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -146,19 +144,21 @@ class AudioClassificationData(DataModule):
         """
 
         ds_kw = dict(
+            sampling_rate=sampling_rate,
+            n_fft=n_fft,
             target_formatter=target_formatter,
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
         )
 
-        train_input = input_cls(RunningStage.TRAINING, train_files, train_targets, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, train_files, train_targets, **ds_kw)
         ds_kw["target_formatter"] = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(RunningStage.VALIDATING, val_files, val_targets, transform=val_transform, **ds_kw),
-            input_cls(RunningStage.TESTING, test_files, test_targets, transform=test_transform, **ds_kw),
-            input_cls(RunningStage.PREDICTING, predict_files, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, val_files, val_targets, **ds_kw),
+            input_cls(RunningStage.TESTING, test_files, test_targets, **ds_kw),
+            input_cls(RunningStage.PREDICTING, predict_files, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -169,20 +169,22 @@ class AudioClassificationData(DataModule):
         val_folder: Optional[str] = None,
         test_folder: Optional[str] = None,
         predict_folder: Optional[str] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        target_formatter: Optional[TargetFormatter] = None,
+        sampling_rate: int = 16000,
+        n_fft: int = 400,
         input_cls: Type[Input] = AudioClassificationFolderInput,
+        transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
         transform_kwargs: Optional[Dict] = None,
+        target_formatter: Optional[TargetFormatter] = None,
         **data_module_kwargs: Any,
     ) -> "AudioClassificationData":
         """Load the :class:`~flash.audio.classification.data.AudioClassificationData` from folders containing
         spectrogram images.
 
-        The supported file extensions are: ``.jpg``, ``.jpeg``, ``.png``, ``.ppm``, ``.bmp``, ``.pgm``, ``.tif``,
-        ``.tiff``, ``.webp``, and ``.npy``.
+        The supported file extensions for precomputed spectrograms are: ``.jpg``, ``.jpeg``, ``.png``, ``.ppm``,
+        ``.bmp``, ``.pgm``, ``.tif``, ``.tiff``, ``.webp``, and ``.npy``.
+        The supported file extensions for raw audio (where spectrograms will be computed automatically) are: ``.aiff``,
+        ``.au``, ``.avr``, ``.caf``, ``.flac``, ``.mat``, ``.mat4``, ``.mat5``, ``.mpc2k``, ``.ogg``, ``.paf``,
+        ``.pvf``, ``.rf64``, ``.ircam``, ``.voc``, ``.w64``, ``.wav``, ``.nist``, and ``.wavex``.
         For train, test, and validation data, the folders are expected to contain a sub-folder for each class.
         Here's the required structure:
 
@@ -215,14 +217,12 @@ class AudioClassificationData(DataModule):
             val_folder: The folder containing spectrogram images to use when validating.
             test_folder: The folder containing spectrogram images to use when testing.
             predict_folder: The folder containing spectrogram images to use when predicting.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-                predicting.
+            sampling_rate: Sampling rate to use when loading raw audio files.
+            n_fft: The size of the FFT to use when creating spectrograms from raw audio.
             target_formatter: Optionally provide a :class:`~flash.core.data.utilities.classification.TargetFormatter` to
                 control how targets are handled. See :ref:`formatting_classification_targets` for more details.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
                 :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -278,19 +278,21 @@ class AudioClassificationData(DataModule):
         """
 
         ds_kw = dict(
+            sampling_rate=sampling_rate,
+            n_fft=n_fft,
             target_formatter=target_formatter,
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
         )
 
-        train_input = input_cls(RunningStage.TRAINING, train_folder, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, train_folder, **ds_kw)
         ds_kw["target_formatter"] = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(RunningStage.VALIDATING, val_folder, transform=val_transform, **ds_kw),
-            input_cls(RunningStage.TESTING, test_folder, transform=test_transform, **ds_kw),
-            input_cls(RunningStage.PREDICTING, predict_folder, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, val_folder, **ds_kw),
+            input_cls(RunningStage.TESTING, test_folder, **ds_kw),
+            input_cls(RunningStage.PREDICTING, predict_folder, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -304,13 +306,10 @@ class AudioClassificationData(DataModule):
         test_data: Optional[Collection[np.ndarray]] = None,
         test_targets: Optional[Sequence[Any]] = None,
         predict_data: Optional[Collection[np.ndarray]] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        target_formatter: Optional[TargetFormatter] = None,
         input_cls: Type[Input] = AudioClassificationNumpyInput,
+        transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
         transform_kwargs: Optional[Dict] = None,
+        target_formatter: Optional[TargetFormatter] = None,
         **data_module_kwargs: Any,
     ) -> "AudioClassificationData":
         """Load the :class:`~flash.audio.classification.data.AudioClassificationData` from numpy arrays (or lists
@@ -329,14 +328,10 @@ class AudioClassificationData(DataModule):
             test_data: The numpy array or list of arrays to use when testing.
             test_targets: The list of targets to use when testing.
             predict_data: The numpy array or list of arrays to use when predicting.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-                predicting.
             target_formatter: Optionally provide a :class:`~flash.core.data.utilities.classification.TargetFormatter` to
                 control how targets are handled. See :ref:`formatting_classification_targets` for more details.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
                 :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -374,38 +369,35 @@ class AudioClassificationData(DataModule):
 
         ds_kw = dict(
             target_formatter=target_formatter,
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
         )
 
-        train_input = input_cls(RunningStage.TRAINING, train_data, train_targets, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, train_data, train_targets, **ds_kw)
         ds_kw["target_formatter"] = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(RunningStage.VALIDATING, val_data, val_targets, transform=val_transform, **ds_kw),
-            input_cls(RunningStage.TESTING, test_data, test_targets, transform=test_transform, **ds_kw),
-            input_cls(RunningStage.PREDICTING, predict_data, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, val_data, val_targets, **ds_kw),
+            input_cls(RunningStage.TESTING, test_data, test_targets, **ds_kw),
+            input_cls(RunningStage.PREDICTING, predict_data, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
     @classmethod
     def from_tensors(
         cls,
-        train_data: Optional[Collection[torch.Tensor]] = None,
+        train_data: Optional[Collection[Tensor]] = None,
         train_targets: Optional[Collection[Any]] = None,
-        val_data: Optional[Collection[torch.Tensor]] = None,
+        val_data: Optional[Collection[Tensor]] = None,
         val_targets: Optional[Sequence[Any]] = None,
-        test_data: Optional[Collection[torch.Tensor]] = None,
+        test_data: Optional[Collection[Tensor]] = None,
         test_targets: Optional[Sequence[Any]] = None,
-        predict_data: Optional[Collection[torch.Tensor]] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        target_formatter: Optional[TargetFormatter] = None,
+        predict_data: Optional[Collection[Tensor]] = None,
         input_cls: Type[Input] = AudioClassificationTensorInput,
+        transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
         transform_kwargs: Optional[Dict] = None,
+        target_formatter: Optional[TargetFormatter] = None,
         **data_module_kwargs: Any,
     ) -> "AudioClassificationData":
         """Load the :class:`~flash.audio.classification.data.AudioClassificationData` from torch tensors (or lists
@@ -424,14 +416,10 @@ class AudioClassificationData(DataModule):
             test_data: The torch tensor or list of tensors to use when testing.
             test_targets: The list of targets to use when testing.
             predict_data: The torch tensor or list of tensors to use when predicting.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-                predicting.
             target_formatter: Optionally provide a :class:`~flash.core.data.utilities.classification.TargetFormatter` to
                 control how targets are handled. See :ref:`formatting_classification_targets` for more details.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
                 :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -469,18 +457,18 @@ class AudioClassificationData(DataModule):
 
         ds_kw = dict(
             target_formatter=target_formatter,
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
         )
 
-        train_input = input_cls(RunningStage.TRAINING, train_data, train_targets, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, train_data, train_targets, **ds_kw)
         ds_kw["target_formatter"] = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(RunningStage.VALIDATING, val_data, val_targets, transform=val_transform, **ds_kw),
-            input_cls(RunningStage.TESTING, test_data, test_targets, transform=test_transform, **ds_kw),
-            input_cls(RunningStage.PREDICTING, predict_data, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, val_data, val_targets, **ds_kw),
+            input_cls(RunningStage.TESTING, test_data, test_targets, **ds_kw),
+            input_cls(RunningStage.PREDICTING, predict_data, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -501,21 +489,23 @@ class AudioClassificationData(DataModule):
         predict_data_frame: Optional[pd.DataFrame] = None,
         predict_images_root: Optional[str] = None,
         predict_resolver: Optional[Callable[[str, str], str]] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        target_formatter: Optional[TargetFormatter] = None,
+        sampling_rate: int = 16000,
+        n_fft: int = 400,
         input_cls: Type[Input] = AudioClassificationDataFrameInput,
+        transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
         transform_kwargs: Optional[Dict] = None,
+        target_formatter: Optional[TargetFormatter] = None,
         **data_module_kwargs: Any,
     ) -> "AudioClassificationData":
         """Load the :class:`~flash.audio.classification.data.AudioClassificationData` from pandas DataFrame objects
         containing spectrogram image file paths and their corresponding targets.
 
         Input spectrogram image paths will be extracted from the ``input_field`` in the DataFrame.
-        The supported file extensions are: ``.jpg``, ``.jpeg``, ``.png``, ``.ppm``, ``.bmp``, ``.pgm``, ``.tif``,
-        ``.tiff``, ``.webp``, and ``.npy``.
+        The supported file extensions for precomputed spectrograms are: ``.jpg``, ``.jpeg``, ``.png``, ``.ppm``,
+        ``.bmp``, ``.pgm``, ``.tif``, ``.tiff``, ``.webp``, and ``.npy``.
+        The supported file extensions for raw audio (where spectrograms will be computed automatically) are: ``.aiff``,
+        ``.au``, ``.avr``, ``.caf``, ``.flac``, ``.mat``, ``.mat4``, ``.mat5``, ``.mpc2k``, ``.ogg``, ``.paf``,
+        ``.pvf``, ``.rf64``, ``.ircam``, ``.voc``, ``.w64``, ``.wav``, ``.nist``, and ``.wavex``.
         The targets will be extracted from the ``target_fields`` in the DataFrame and can be in any of our
         :ref:`supported classification target formats <formatting_classification_targets>`.
         To learn how to customize the transforms applied for each stage, read our
@@ -540,14 +530,12 @@ class AudioClassificationData(DataModule):
             predict_images_root: The root directory containing predict spectrogram images.
             predict_resolver: Optionally provide a function which converts an entry from the ``input_field`` into a
                 spectrogram image file path.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-                predicting.
+            sampling_rate: Sampling rate to use when loading raw audio files.
+            n_fft: The size of the FFT to use when creating spectrograms from raw audio.
             target_formatter: Optionally provide a :class:`~flash.core.data.utilities.classification.TargetFormatter` to
                 control how targets are handled. See :ref:`formatting_classification_targets` for more details.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
                 :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -622,9 +610,9 @@ class AudioClassificationData(DataModule):
         """
 
         ds_kw = dict(
+            sampling_rate=sampling_rate,
+            n_fft=n_fft,
             target_formatter=target_formatter,
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
         )
 
         train_data = (train_data_frame, input_field, target_fields, train_images_root, train_resolver)
@@ -632,14 +620,16 @@ class AudioClassificationData(DataModule):
         test_data = (test_data_frame, input_field, target_fields, test_images_root, test_resolver)
         predict_data = (predict_data_frame, input_field, None, predict_images_root, predict_resolver)
 
-        train_input = input_cls(RunningStage.TRAINING, *train_data, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, *train_data, **ds_kw)
         ds_kw["target_formatter"] = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(RunningStage.VALIDATING, *val_data, transform=val_transform, **ds_kw),
-            input_cls(RunningStage.TESTING, *test_data, transform=test_transform, **ds_kw),
-            input_cls(RunningStage.PREDICTING, *predict_data, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, *val_data, **ds_kw),
+            input_cls(RunningStage.TESTING, *test_data, **ds_kw),
+            input_cls(RunningStage.PREDICTING, *predict_data, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -660,21 +650,23 @@ class AudioClassificationData(DataModule):
         predict_file: Optional[str] = None,
         predict_images_root: Optional[str] = None,
         predict_resolver: Optional[Callable[[PATH_TYPE, Any], PATH_TYPE]] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
-        target_formatter: Optional[TargetFormatter] = None,
+        sampling_rate: int = 16000,
+        n_fft: int = 400,
         input_cls: Type[Input] = AudioClassificationCSVInput,
+        transform: INPUT_TRANSFORM_TYPE = AudioClassificationInputTransform,
         transform_kwargs: Optional[Dict] = None,
+        target_formatter: Optional[TargetFormatter] = None,
         **data_module_kwargs: Any,
     ) -> "AudioClassificationData":
         """Load the :class:`~flash.audio.classification.data.AudioClassificationData` from CSV files containing
         spectrogram image file paths and their corresponding targets.
 
         Input spectrogram images will be extracted from the ``input_field`` column in the CSV files.
-        The supported file extensions are: ``.jpg``, ``.jpeg``, ``.png``, ``.ppm``, ``.bmp``, ``.pgm``, ``.tif``,
-        ``.tiff``, ``.webp``, and ``.npy``.
+        The supported file extensions for precomputed spectrograms are: ``.jpg``, ``.jpeg``, ``.png``, ``.ppm``,
+        ``.bmp``, ``.pgm``, ``.tif``, ``.tiff``, ``.webp``, and ``.npy``.
+        The supported file extensions for raw audio (where spectrograms will be computed automatically) are: ``.aiff``,
+        ``.au``, ``.avr``, ``.caf``, ``.flac``, ``.mat``, ``.mat4``, ``.mat5``, ``.mpc2k``, ``.ogg``, ``.paf``,
+        ``.pvf``, ``.rf64``, ``.ircam``, ``.voc``, ``.w64``, ``.wav``, ``.nist``, and ``.wavex``.
         The targets will be extracted from the ``target_fields`` in the CSV files and can be in any of our
         :ref:`supported classification target formats <formatting_classification_targets>`.
         To learn how to customize the transforms applied for each stage, read our
@@ -699,14 +691,12 @@ class AudioClassificationData(DataModule):
             predict_images_root: The root directory containing predict spectrogram images.
             predict_resolver: Optionally provide a function which converts an entry from the ``input_field`` into a
                 spectrogram image file path.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-                predicting.
+            sampling_rate: Sampling rate to use when loading raw audio files.
+            n_fft: The size of the FFT to use when creating spectrograms from raw audio.
             target_formatter: Optionally provide a :class:`~flash.core.data.utilities.classification.TargetFormatter` to
                 control how targets are handled. See :ref:`formatting_classification_targets` for more details.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
                 :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -717,6 +707,8 @@ class AudioClassificationData(DataModule):
         Examples
         ________
 
+        The files can be in Comma Separated Values (CSV) format with either a ``.csv`` or ``.txt`` extension.
+
         .. testsetup::
 
             >>> import os
@@ -788,12 +780,86 @@ class AudioClassificationData(DataModule):
             >>> shutil.rmtree("predict_folder")
             >>> os.remove("train_data.csv")
             >>> os.remove("predict_data.csv")
+
+        Alternatively, the files can be in Tab Separated Values (TSV) format with a ``.tsv`` extension.
+
+        .. testsetup::
+
+            >>> import os
+            >>> from PIL import Image
+            >>> from pandas import DataFrame
+            >>> rand_image = Image.fromarray(np.random.randint(0, 255, (64, 64, 3), dtype="uint8"))
+            >>> os.makedirs("train_folder", exist_ok=True)
+            >>> os.makedirs("predict_folder", exist_ok=True)
+            >>> _ = [rand_image.save(os.path.join("train_folder", f"spectrogram_{i}.png")) for i in range(1, 4)]
+            >>> _ = [rand_image.save(
+            ...     os.path.join("predict_folder", f"predict_spectrogram_{i}.png")
+            ... ) for i in range(1, 4)]
+            >>> DataFrame.from_dict({
+            ...     "images": ["spectrogram_1.png", "spectrogram_2.png", "spectrogram_3.png"],
+            ...     "targets": ["meow", "bark", "meow"],
+            ... }).to_csv("train_data.tsv", sep="\\t", index=False)
+            >>> DataFrame.from_dict({
+            ...     "images": ["predict_spectrogram_1.png", "predict_spectrogram_2.png", "predict_spectrogram_3.png"],
+            ... }).to_csv("predict_data.tsv", sep="\\t", index=False)
+
+        The file ``train_data.tsv`` contains the following:
+
+        .. code-block::
+
+            images              targets
+            spectrogram_1.png   meow
+            spectrogram_2.png   bark
+            spectrogram_3.png   meow
+
+        The file ``predict_data.tsv`` contains the following:
+
+        .. code-block::
+
+            images
+            predict_spectrogram_1.png
+            predict_spectrogram_2.png
+            predict_spectrogram_3.png
+
+        .. doctest::
+
+            >>> from flash import Trainer
+            >>> from flash.audio import AudioClassificationData
+            >>> from flash.image import ImageClassifier
+            >>> datamodule = AudioClassificationData.from_csv(
+            ...     "images",
+            ...     "targets",
+            ...     train_file="train_data.tsv",
+            ...     train_images_root="train_folder",
+            ...     predict_file="predict_data.tsv",
+            ...     predict_images_root="predict_folder",
+            ...     transform_kwargs=dict(spectrogram_size=(128, 128)),
+            ...     batch_size=2,
+            ... )
+            >>> datamodule.num_classes
+            2
+            >>> datamodule.labels
+            ['bark', 'meow']
+            >>> model = ImageClassifier(backbone="resnet18", num_classes=datamodule.num_classes)
+            >>> trainer = Trainer(fast_dev_run=True)
+            >>> trainer.fit(model, datamodule=datamodule)  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
+            Training...
+            >>> trainer.predict(model, datamodule=datamodule)  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
+            Predicting...
+
+        .. testcleanup::
+
+            >>> import shutil
+            >>> shutil.rmtree("train_folder")
+            >>> shutil.rmtree("predict_folder")
+            >>> os.remove("train_data.tsv")
+            >>> os.remove("predict_data.tsv")
         """
 
         ds_kw = dict(
+            sampling_rate=sampling_rate,
+            n_fft=n_fft,
             target_formatter=target_formatter,
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
         )
 
         train_data = (train_file, input_field, target_fields, train_images_root, train_resolver)
@@ -801,14 +867,16 @@ class AudioClassificationData(DataModule):
         test_data = (test_file, input_field, target_fields, test_images_root, test_resolver)
         predict_data = (predict_file, input_field, None, predict_images_root, predict_resolver)
 
-        train_input = input_cls(RunningStage.TRAINING, *train_data, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, *train_data, **ds_kw)
         ds_kw["target_formatter"] = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(RunningStage.VALIDATING, *val_data, transform=val_transform, **ds_kw),
-            input_cls(RunningStage.TESTING, *test_data, transform=test_transform, **ds_kw),
-            input_cls(RunningStage.PREDICTING, *predict_data, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, *val_data, **ds_kw),
+            input_cls(RunningStage.TESTING, *test_data, **ds_kw),
+            input_cls(RunningStage.PREDICTING, *predict_data, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
