@@ -11,21 +11,21 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict, List, Set
+from typing import Any, Dict, List, Set, Tuple
 
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 
 from flash.core.data.callback import BaseDataFetcher
 from flash.core.data.utils import _CALLBACK_FUNCS
-from flash.core.utilities.apply_func import _is_overriden
+from flash.core.utilities.apply_func import _is_overridden
 from flash.core.utilities.stages import RunningStage
 
 
 class BaseVisualization(BaseDataFetcher):
-    """This Base Class is used to create visualization tool on top of :class:`~flash.core.data.process.Preprocess`
-    hooks.
+    """This Base Class is used to create visualization tool on top of
+    :class:`~flash.core.data.io.input_transform.InputTransform` hooks.
 
-    Override any of the ``show_{preprocess_hook_name}`` to receive the associated data and visualize them.
+    Override any of the ``show_{_hook_name}`` to receive the associated data and visualize them.
 
     Example::
 
@@ -37,13 +37,7 @@ class BaseVisualization(BaseDataFetcher):
             def show_load_sample(self, samples: List[Any], running_stage):
                 # plot samples
 
-            def show_pre_tensor_transform(self, samples: List[Any], running_stage):
-                # plot samples
-
-            def show_to_tensor_transform(self, samples: List[Any], running_stage):
-                # plot samples
-
-            def show_post_tensor_transform(self, samples: List[Any], running_stage):
+            def show_per_sample_transform(self, samples: List[Any], running_stage):
                 # plot samples
 
             def show_collate(self, batch: List[Any], running_stage):
@@ -93,24 +87,35 @@ class BaseVisualization(BaseDataFetcher):
                 # out
                 {
                     'load_sample': [...],
-                    'pre_tensor_transform': [...],
-                    'to_tensor_transform': [...],
-                    'post_tensor_transform': [...],
+                    'per_sample_transform': [...],
                     'collate': [...],
                     'per_batch_transform': [...],
                 }
 
     .. note::
 
-        As the :class:`~flash.core.data.process.Preprocess` hooks are injected within
+        As the :class:`~flash.core.data.io.input_transform.InputTransform` hooks are injected within
         the threaded workers of the DataLoader,
         the data won't be accessible when using ``num_workers > 0``.
     """
 
-    def _show(self, running_stage: RunningStage, func_names_list: List[str]) -> None:
-        self.show(self.batches[running_stage], running_stage, func_names_list)
+    def _show(
+        self,
+        running_stage: RunningStage,
+        func_names_list: List[str],
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
+        self.show(self.batches[running_stage], running_stage, func_names_list, limit_nb_samples, figsize)
 
-    def show(self, batch: Dict[str, Any], running_stage: RunningStage, func_names_list: List[str]) -> None:
+    def show(
+        self,
+        batch: Dict[str, Any],
+        running_stage: RunningStage,
+        func_names_list: List[str],
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
         """Override this function when you want to visualize a composition."""
         # filter out the functions to visualise
         func_names_set: Set[str] = set(func_names_list) & set(_CALLBACK_FUNCS)
@@ -119,29 +124,59 @@ class BaseVisualization(BaseDataFetcher):
 
         for func_name in func_names_set:
             hook_name = f"show_{func_name}"
-            if _is_overriden(hook_name, self, BaseVisualization):
-                getattr(self, hook_name)(batch[func_name], running_stage)
+            if _is_overridden(hook_name, self, BaseVisualization):
+                getattr(self, hook_name)(batch[func_name], running_stage, limit_nb_samples, figsize)
 
-    def show_load_sample(self, samples: List[Any], running_stage: RunningStage):
-        """Override to visualize preprocess ``load_sample`` output data."""
+    def show_load_sample(
+        self,
+        samples: List[Any],
+        running_stage: RunningStage,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ):
+        """Override to visualize  ``load_sample`` output data."""
 
-    def show_pre_tensor_transform(self, samples: List[Any], running_stage: RunningStage):
-        """Override to visualize preprocess ``pre_tensor_transform`` output data."""
+    def show_per_sample_transform(
+        self,
+        samples: List[Any],
+        running_stage: RunningStage,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ):
+        """Override to visualize ``per_sample_transform`` output data."""
 
-    def show_to_tensor_transform(self, samples: List[Any], running_stage: RunningStage):
-        """Override to visualize preprocess ``to_tensor_transform`` output data."""
+    def show_collate(
+        self,
+        batch: List[Any],
+        running_stage: RunningStage,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
+        """Override to visualize  ``collate`` output data."""
 
-    def show_post_tensor_transform(self, samples: List[Any], running_stage: RunningStage):
-        """Override to visualize preprocess ``post_tensor_transform`` output data."""
+    def show_per_batch_transform(
+        self,
+        batch: List[Any],
+        running_stage: RunningStage,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
+        """Override to visualize  ``per_batch_transform`` output data."""
 
-    def show_collate(self, batch: List[Any], running_stage: RunningStage) -> None:
-        """Override to visualize preprocess ``collate`` output data."""
+    def show_per_sample_transform_on_device(
+        self,
+        samples: List[Any],
+        running_stage: RunningStage,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
+        """Override to visualize  ``per_sample_transform_on_device`` output data."""
 
-    def show_per_batch_transform(self, batch: List[Any], running_stage: RunningStage) -> None:
-        """Override to visualize preprocess ``per_batch_transform`` output data."""
-
-    def show_per_sample_transform_on_device(self, samples: List[Any], running_stage: RunningStage) -> None:
-        """Override to visualize preprocess ``per_sample_transform_on_device`` output data."""
-
-    def show_per_batch_transform_on_device(self, batch: List[Any], running_stage: RunningStage) -> None:
-        """Override to visualize preprocess ``per_batch_transform_on_device`` output data."""
+    def show_per_batch_transform_on_device(
+        self,
+        batch: List[Any],
+        running_stage: RunningStage,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
+        """Override to visualize  ``per_batch_transform_on_device`` output data."""
