@@ -19,25 +19,28 @@ import pytorch_lightning as pl
 import torch
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from torch.utils.data import DataLoader, Dataset
-from torch.utils.data._utils.collate import default_collate
 from torch.utils.data.dataset import IterableDataset
 from torch.utils.data.sampler import Sampler
 
 import flash
 from flash.core.data.base_viz import BaseVisualization
 from flash.core.data.callback import BaseDataFetcher
-from flash.core.data.io.input import DataKeys, Input, InputBase, IterableInput
+from flash.core.data.io.input import DataKeys, Input, IterableInput
 from flash.core.data.io.input_transform import (
-    _create_collate_input_transform_processors,
-    _InputTransformProcessorV2,
-    create_transform,
+    create_device_input_transform_processor,
+    create_or_configure_input_transform,
+    create_worker_input_transform_processor,
     InputTransform,
 )
-from flash.core.data.io.output_transform import OutputTransform
 from flash.core.data.splits import SplitDataset
 from flash.core.data.utils import _STAGES_PREFIX
-from flash.core.registry import FlashRegistry
+from flash.core.utilities.imports import _CORE_TESTING
 from flash.core.utilities.stages import RunningStage
+from flash.core.utilities.types import INPUT_TRANSFORM_TYPE
+
+# Skip doctests if requirements aren't available
+if not _CORE_TESTING:
+    __doctest_skip__ = ["DataModule"]
 
 
 class DatasetInput(Input):
@@ -63,6 +66,8 @@ class DataModule(pl.LightningDataModule):
         data_fetcher: The :class:`~flash.core.data.callback.BaseDataFetcher` to attach to the
             :class:`~flash.core.data.io.input_transform.InputTransform`. If ``None``, the output from
             :meth:`~flash.core.data.data_module.DataModule.configure_data_fetcher` will be used.
+        transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
+        transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
         val_split: An optional float which gives the relative amount of the training dataset to use for the validation
             dataset.
         batch_size: The batch size to be used by the DataLoader.
@@ -103,7 +108,6 @@ class DataModule(pl.LightningDataModule):
     """
 
     input_transform_cls = InputTransform
-    input_transforms_registry: Optional[FlashRegistry] = None
 
     def __init__(
         self,
@@ -112,6 +116,8 @@ class DataModule(pl.LightningDataModule):
         test_input: Optional[Input] = None,
         predict_input: Optional[Input] = None,
         data_fetcher: Optional[BaseDataFetcher] = None,
+        transform: INPUT_TRANSFORM_TYPE = InputTransform,
+        transform_kwargs: Optional[Dict] = None,
         val_split: Optional[float] = None,
         batch_size: Optional[int] = None,
         num_workers: int = 0,
@@ -126,8 +132,11 @@ class DataModule(pl.LightningDataModule):
         if flash._IS_TESTING and torch.cuda.is_available():
             batch_size = 16
 
-        self._input_transform: Optional[OutputTransform] = None
-        self._viz: Optional[BaseVisualization] = None
+        self.input_transform = create_or_configure_input_transform(
+            transform=transform, transform_kwargs=transform_kwargs
+        )
+
+        self.viz: Optional[BaseVisualization] = None
 
         self._train_input = train_input
         self._val_input = val_input
@@ -144,19 +153,7 @@ class DataModule(pl.LightningDataModule):
 
         self._data_fetcher: Optional[BaseDataFetcher] = data_fetcher or self.configure_data_fetcher()
 
-        self._train_dataloader_collate_fn = self._resolve_dataloader_collate_fn(self._train_input)
-        self._val_dataloader_collate_fn = self._resolve_dataloader_collate_fn(self._val_input)
-        self._test_dataloader_collate_fn = self._resolve_dataloader_collate_fn(self._test_input)
-        self._predict_dataloader_collate_fn = self._resolve_dataloader_collate_fn(self._predict_input)
-
-        self._on_after_batch_transfer_fns = {
-            RunningStage.TRAINING: self._resolve_on_after_batch_transfer_fn(self._train_input),
-            RunningStage.VALIDATING: self._resolve_on_after_batch_transfer_fn(self._val_input),
-            RunningStage.SANITY_CHECKING: self._resolve_on_after_batch_transfer_fn(self._val_input),
-            RunningStage.TESTING: self._resolve_on_after_batch_transfer_fn(self._test_input),
-            RunningStage.PREDICTING: self._resolve_on_after_batch_transfer_fn(self._predict_input),
-        }
-        self._model_on_after_batch_transfer_fns = None
+        self._on_after_batch_transfer_fns = None
 
         if self._train_input:
             self.train_dataloader = self._train_dataloader
@@ -200,33 +197,26 @@ class DataModule(pl.LightningDataModule):
         """This property returns the prediction dataset."""
         return self._predict_input
 
-    def _resolve_dataloader_collate_fn(self, ds: Optional[Input]) -> Optional[Callable]:
-        if not ds:
-            return None
-        if isinstance(ds.transform, InputTransform):
-            return ds._create_dataloader_collate_fn([self.data_fetcher])
-        return default_collate
+    #####################################
+    # METHODS PERTAINING TO DATALOADERS #
+    #####################################
 
-    def _resolve_on_after_batch_transfer_fn(self, ds: Optional[Input]) -> Optional[Callable]:
-        if not ds:
-            return None
-        if isinstance(ds.transform, InputTransform):
-            return ds._create_on_after_batch_transfer_fn([self.data_fetcher])
+    def _resolve_input_transform(self) -> Optional[InputTransform]:
+        input_transform = self.input_transform
+        if (
+            isinstance(getattr(self, "trainer", None), pl.Trainer)
+            and getattr(self.trainer.lightning_module, "input_transform", None) is not None
+        ):
+            input_transform = create_or_configure_input_transform(self.trainer.lightning_module.input_transform)
+
+        if input_transform is not None:
+            input_transform.callbacks = [self.data_fetcher]
+        return input_transform
 
     def _train_dataloader(self) -> DataLoader:
         train_ds: Input = self._train_input
 
-        collate_fn = self._train_dataloader_collate_fn
-        if isinstance(getattr(self, "trainer", None), pl.Trainer):
-            input_transform = getattr(self.trainer.lightning_module, "input_transform", None)
-            if input_transform is not None:
-                input_transform = create_transform(input_transform, RunningStage.TRAINING)
-                collate_fn = _create_collate_input_transform_processors(input_transform, [self.data_fetcher])[0]
-
-        transform_processor = None
-        if isinstance(collate_fn, _InputTransformProcessorV2):
-            transform_processor = collate_fn
-            collate_fn = transform_processor.collate_fn
+        input_transform = self._resolve_input_transform()
 
         shuffle: bool = False
         if isinstance(train_ds, IterableDataset):
@@ -247,15 +237,15 @@ class DataModule(pl.LightningDataModule):
         ):
             dataloader = self.trainer.lightning_module.process_train_dataset(
                 train_ds,
-                trainer=self.trainer,
-                batch_size=self.batch_size,
+                self.batch_size,
                 num_workers=self.num_workers,
                 pin_memory=self.pin_memory,
                 shuffle=shuffle,
                 drop_last=drop_last,
-                collate_fn=collate_fn,
                 sampler=sampler,
                 persistent_workers=self.persistent_workers,
+                input_transform=input_transform,
+                trainer=self.trainer,
             )
         else:
             dataloader = DataLoader(
@@ -266,43 +256,29 @@ class DataModule(pl.LightningDataModule):
                 num_workers=self.num_workers,
                 pin_memory=self.pin_memory,
                 drop_last=drop_last,
-                collate_fn=collate_fn,
+                collate_fn=create_worker_input_transform_processor(RunningStage.TRAINING, input_transform),
                 persistent_workers=self.persistent_workers,
             )
 
-        if transform_processor is not None:
-            transform_processor.collate_fn = dataloader.collate_fn
-            dataloader.collate_fn = transform_processor
-
-        self._model_on_after_batch_transfer_fns = None
+        self._on_after_batch_transfer_fns = None
         return dataloader
 
     def _val_dataloader(self) -> DataLoader:
         val_ds: Input = self._val_input
 
-        collate_fn = self._val_dataloader_collate_fn
-        if isinstance(getattr(self, "trainer", None), pl.Trainer):
-            input_transform = getattr(self.trainer.lightning_module, "input_transform", None)
-            if input_transform is not None:
-                input_transform = create_transform(input_transform, RunningStage.VALIDATING)
-                collate_fn = _create_collate_input_transform_processors(input_transform, [self.data_fetcher])[0]
-
-        transform_processor = None
-        if isinstance(collate_fn, _InputTransformProcessorV2):
-            transform_processor = collate_fn
-            collate_fn = transform_processor.collate_fn
+        input_transform = self._resolve_input_transform()
 
         if isinstance(getattr(self, "trainer", None), pl.Trainer) and hasattr(
             self.trainer.lightning_module, "process_val_dataset"
         ):
             dataloader = self.trainer.lightning_module.process_val_dataset(
                 val_ds,
-                trainer=self.trainer,
-                batch_size=self.batch_size,
+                self.batch_size,
                 num_workers=self.num_workers,
                 pin_memory=self.pin_memory,
-                collate_fn=collate_fn,
                 persistent_workers=self.persistent_workers,
+                input_transform=input_transform,
+                trainer=self.trainer,
             )
         else:
             dataloader = DataLoader(
@@ -310,43 +286,29 @@ class DataModule(pl.LightningDataModule):
                 batch_size=self.batch_size,
                 num_workers=self.num_workers,
                 pin_memory=self.pin_memory,
-                collate_fn=collate_fn,
+                collate_fn=create_worker_input_transform_processor(RunningStage.VALIDATING, input_transform),
                 persistent_workers=self.persistent_workers,
             )
 
-        if transform_processor is not None:
-            transform_processor.collate_fn = dataloader.collate_fn
-            dataloader.collate_fn = transform_processor
-
-        self._model_on_after_batch_transfer_fns = None
+        self._on_after_batch_transfer_fns = None
         return dataloader
 
     def _test_dataloader(self) -> DataLoader:
         test_ds: Input = self._test_input
 
-        collate_fn = self._test_dataloader_collate_fn
-        if isinstance(getattr(self, "trainer", None), pl.Trainer):
-            input_transform = getattr(self.trainer.lightning_module, "input_transform", None)
-            if input_transform is not None:
-                input_transform = create_transform(input_transform, RunningStage.TESTING)
-                collate_fn = _create_collate_input_transform_processors(input_transform, [self.data_fetcher])[0]
-
-        transform_processor = None
-        if isinstance(collate_fn, _InputTransformProcessorV2):
-            transform_processor = collate_fn
-            collate_fn = transform_processor.collate_fn
+        input_transform = self._resolve_input_transform()
 
         if isinstance(getattr(self, "trainer", None), pl.Trainer) and hasattr(
             self.trainer.lightning_module, "process_test_dataset"
         ):
             dataloader = self.trainer.lightning_module.process_test_dataset(
                 test_ds,
-                trainer=self.trainer,
-                batch_size=self.batch_size,
+                self.batch_size,
                 num_workers=self.num_workers,
                 pin_memory=self.pin_memory,
-                collate_fn=collate_fn,
                 persistent_workers=self.persistent_workers,
+                input_transform=input_transform,
+                trainer=self.trainer,
             )
         else:
             dataloader = DataLoader(
@@ -354,31 +316,17 @@ class DataModule(pl.LightningDataModule):
                 batch_size=self.batch_size,
                 num_workers=self.num_workers,
                 pin_memory=self.pin_memory,
-                collate_fn=collate_fn,
+                collate_fn=create_worker_input_transform_processor(RunningStage.TESTING, input_transform),
                 persistent_workers=self.persistent_workers,
             )
 
-        if transform_processor is not None:
-            transform_processor.collate_fn = dataloader.collate_fn
-            dataloader.collate_fn = transform_processor
-
-        self._model_on_after_batch_transfer_fns = None
+        self._on_after_batch_transfer_fns = None
         return dataloader
 
     def _predict_dataloader(self) -> DataLoader:
         predict_ds: Input = self._predict_input
 
-        collate_fn = self._predict_dataloader_collate_fn
-        if isinstance(getattr(self, "trainer", None), pl.Trainer):
-            input_transform = getattr(self.trainer.lightning_module, "input_transform", None)
-            if input_transform is not None:
-                input_transform = create_transform(input_transform, RunningStage.PREDICTING)
-                collate_fn = _create_collate_input_transform_processors(input_transform, [self.data_fetcher])[0]
-
-        transform_processor = None
-        if isinstance(collate_fn, _InputTransformProcessorV2):
-            transform_processor = collate_fn
-            collate_fn = transform_processor.collate_fn
+        input_transform = self._resolve_input_transform()
 
         if isinstance(predict_ds, IterableDataset):
             batch_size = self.batch_size
@@ -390,11 +338,12 @@ class DataModule(pl.LightningDataModule):
         ):
             dataloader = self.trainer.lightning_module.process_predict_dataset(
                 predict_ds,
-                batch_size=batch_size,
+                self.batch_size,
                 num_workers=self.num_workers,
                 pin_memory=self.pin_memory,
-                collate_fn=collate_fn,
                 persistent_workers=self.persistent_workers,
+                input_transform=input_transform,
+                trainer=self.trainer,
             )
         else:
             dataloader = DataLoader(
@@ -402,19 +351,19 @@ class DataModule(pl.LightningDataModule):
                 batch_size=batch_size,
                 num_workers=self.num_workers,
                 pin_memory=self.pin_memory,
-                collate_fn=collate_fn,
+                collate_fn=create_worker_input_transform_processor(RunningStage.PREDICTING, input_transform),
                 persistent_workers=self.persistent_workers,
             )
 
-        if transform_processor is not None:
-            transform_processor.collate_fn = dataloader.collate_fn
-            dataloader.collate_fn = transform_processor
-
-        self._model_on_after_batch_transfer_fns = None
+        self._on_after_batch_transfer_fns = None
         return dataloader
 
-    def _load_model_on_after_batch_transfer_fns(self) -> None:
-        self._model_on_after_batch_transfer_fns = {}
+    ############################################################
+    # METHODS RELATED TO on_after_batch_transfer FUNCTIONALITY #
+    ############################################################
+
+    def _load_on_after_batch_transfer_fns(self) -> None:
+        self._on_after_batch_transfer_fns = {}
 
         for stage in [
             RunningStage.TRAINING,
@@ -423,40 +372,35 @@ class DataModule(pl.LightningDataModule):
             RunningStage.TESTING,
             RunningStage.PREDICTING,
         ]:
-            transform = None
-            if isinstance(getattr(self, "trainer", None), pl.Trainer):
-                input_transform = getattr(self.trainer.lightning_module, "input_transform", None)
-                if input_transform is not None:
-                    input_transform = create_transform(
-                        input_transform, stage if stage != RunningStage.SANITY_CHECKING else RunningStage.VALIDATING
-                    )
-                    transform = _create_collate_input_transform_processors(input_transform, [self.data_fetcher])[1]
-            self._model_on_after_batch_transfer_fns[stage] = transform
+            input_transform = self._resolve_input_transform()
+
+            if input_transform is not None:
+                transform = create_device_input_transform_processor(
+                    stage if stage != RunningStage.SANITY_CHECKING else RunningStage.VALIDATING,
+                    input_transform,
+                )
+                self._on_after_batch_transfer_fns[stage] = transform
+            else:
+                self._on_after_batch_transfer_fns[stage] = None
 
     def on_after_batch_transfer(self, batch: Any, dataloader_idx: int) -> Any:
         if getattr(self, "trainer", None) is None:
             return batch
 
-        if self._model_on_after_batch_transfer_fns is None:
-            self._load_model_on_after_batch_transfer_fns()
+        if self._on_after_batch_transfer_fns is None:
+            self._load_on_after_batch_transfer_fns()
 
         stage = self.trainer.state.stage
 
-        transform = self._model_on_after_batch_transfer_fns[stage]
-        if transform is None:
-            transform = self._on_after_batch_transfer_fns[stage]
+        transform = self._on_after_batch_transfer_fns[stage]
 
         if transform:
             batch = transform(batch)
         return batch
 
-    @property
-    def viz(self) -> BaseVisualization:
-        return self._viz or DataModule.configure_data_fetcher()
-
-    @viz.setter
-    def viz(self, viz: BaseVisualization) -> None:
-        self._viz = viz
+    ###################################
+    # METHODS RELATED TO DATA FETCHER #
+    ###################################
 
     @staticmethod
     def configure_data_fetcher(*args, **kwargs) -> BaseDataFetcher:
@@ -475,6 +419,31 @@ class DataModule(pl.LightningDataModule):
     def data_fetcher(self, data_fetcher: BaseDataFetcher) -> None:
         self._data_fetcher = data_fetcher
 
+    ######################################
+    # METHODS RELATED TO INPUT TRANSFORM #
+    ######################################
+
+    @property
+    def input_transform(self) -> InputTransform:
+        """This property returns the data fetcher."""
+        return self._input_transform
+
+    @input_transform.setter
+    def input_transform(self, input_transform: InputTransform) -> None:
+        self._input_transform = input_transform
+
+    ####################################
+    # METHODS RELATED TO VISUALIZATION #
+    ####################################
+
+    @property
+    def viz(self) -> BaseVisualization:
+        return self._viz or DataModule.configure_data_fetcher()
+
+    @viz.setter
+    def viz(self, viz: BaseVisualization) -> None:
+        self._viz = viz
+
     def _reset_iterator(self, stage: str) -> Iterable[Any]:
         iter_name = f"_{stage}_iter"
         # num_workers has to be set to 0 to work properly
@@ -486,7 +455,14 @@ class DataModule(pl.LightningDataModule):
         setattr(self, iter_name, iterator)
         return iterator
 
-    def _show_batch(self, stage: str, func_names: Union[str, List[str]], reset: bool = True) -> None:
+    def _show_batch(
+        self,
+        stage: str,
+        func_names: Union[str, List[str]],
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+        reset: bool = True,
+    ) -> None:
         """This function is used to handle transforms profiling for batch visualization."""
         # don't show in CI
         if os.getenv("FLASH_TESTING", "0") == "1":
@@ -500,6 +476,9 @@ class DataModule(pl.LightningDataModule):
         if isinstance(func_names, str):
             func_names = [func_names]
 
+        if not limit_nb_samples:
+            limit_nb_samples = self.batch_size
+
         iter_dataloader = getattr(self, iter_name)
         with self.data_fetcher.enable():
             if reset:
@@ -510,29 +489,53 @@ class DataModule(pl.LightningDataModule):
                 iter_dataloader = self._reset_iterator(stage)
                 _ = next(iter_dataloader)
             data_fetcher: BaseVisualization = self.data_fetcher
-            data_fetcher._show(stage, func_names)
+            data_fetcher._show(stage, func_names, limit_nb_samples, figsize)
             if reset:
                 self.data_fetcher.batches[stage] = {}
 
-    def show_train_batch(self, hooks_names: Union[str, List[str]] = "load_sample", reset: bool = True) -> None:
+    def show_train_batch(
+        self,
+        hooks_names: Union[str, List[str]] = "load_sample",
+        reset: bool = True,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
         """This function is used to visualize a batch from the train dataloader."""
         stage_name: str = _STAGES_PREFIX[RunningStage.TRAINING]
-        self._show_batch(stage_name, hooks_names, reset=reset)
+        self._show_batch(stage_name, hooks_names, limit_nb_samples, figsize, reset=reset)
 
-    def show_val_batch(self, hooks_names: Union[str, List[str]] = "load_sample", reset: bool = True) -> None:
+    def show_val_batch(
+        self,
+        hooks_names: Union[str, List[str]] = "load_sample",
+        reset: bool = True,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
         """This function is used to visualize a batch from the validation dataloader."""
         stage_name: str = _STAGES_PREFIX[RunningStage.VALIDATING]
-        self._show_batch(stage_name, hooks_names, reset=reset)
+        self._show_batch(stage_name, hooks_names, limit_nb_samples, figsize, reset=reset)
 
-    def show_test_batch(self, hooks_names: Union[str, List[str]] = "load_sample", reset: bool = True) -> None:
+    def show_test_batch(
+        self,
+        hooks_names: Union[str, List[str]] = "load_sample",
+        reset: bool = True,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
         """This function is used to visualize a batch from the test dataloader."""
         stage_name: str = _STAGES_PREFIX[RunningStage.TESTING]
-        self._show_batch(stage_name, hooks_names, reset=reset)
+        self._show_batch(stage_name, hooks_names, limit_nb_samples, figsize, reset=reset)
 
-    def show_predict_batch(self, hooks_names: Union[str, List[str]] = "load_sample", reset: bool = True) -> None:
+    def show_predict_batch(
+        self,
+        hooks_names: Union[str, List[str]] = "load_sample",
+        reset: bool = True,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ) -> None:
         """This function is used to visualize a batch from the prediction dataloader."""
         stage_name: str = _STAGES_PREFIX[RunningStage.PREDICTING]
-        self._show_batch(stage_name, hooks_names, reset=reset)
+        self._show_batch(stage_name, hooks_names, limit_nb_samples, figsize, reset=reset)
 
     def _get_property(self, property_name: str) -> Optional[Any]:
         train = getattr(self.train_dataset, property_name, None)
@@ -556,12 +559,6 @@ class DataModule(pl.LightningDataModule):
         """Property that returns ``True`` if this ``DataModule`` contains multi-label data."""
         return self._get_property("multi_label")
 
-    @property
-    def inputs(self) -> Optional[Union[Input, List[InputBase]]]:
-        """Property that returns the inputs associated with this ``DataModule``."""
-        inputs = [self.train_dataset, self.val_dataset, self.test_dataset, self.predict_dataset]
-        return [input for input in inputs if input]
-
     @staticmethod
     def _split_train_val(
         train_dataset: Dataset,
@@ -593,6 +590,10 @@ class DataModule(pl.LightningDataModule):
         val_indices = indices[:val_num_samples]
         train_indices = indices[val_num_samples:]
         return (
-            SplitDataset(train_dataset, train_indices, use_duplicated_indices=True),
-            SplitDataset(train_dataset, val_indices, use_duplicated_indices=True),
+            SplitDataset(
+                train_dataset, train_indices, running_stage=RunningStage.TRAINING, use_duplicated_indices=True
+            ),
+            SplitDataset(
+                train_dataset, val_indices, running_stage=RunningStage.VALIDATING, use_duplicated_indices=True
+            ),
         )
