@@ -14,21 +14,16 @@
 import functools
 import os
 import sys
-from copy import deepcopy
-from functools import partial
-from typing import Any, Callable, cast, Dict, Iterable, List, Optional, Sequence, Tuple, Type, Union
+from enum import Enum
+from typing import Any, cast, Dict, Iterable, List, Sequence, Tuple, Union
 
 from pytorch_lightning.utilities.enums import LightningEnum
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from torch.utils.data import Dataset
 
-import flash
-from flash.core.data.callback import FlashCallback
 from flash.core.data.properties import Properties
 from flash.core.data.utils import _STAGES_PREFIX
-from flash.core.registry import FlashRegistry
 from flash.core.utilities.stages import RunningStage
-from flash.core.utilities.types import INPUT_TRANSFORM_TYPE
 
 if sys.version_info < (3, 7):
     from typing import GenericMeta
@@ -44,6 +39,13 @@ else:
     IterableDataset = object
 
 
+def _deepcopy_dict(nested_dict: Any) -> Any:
+    """Utility to deepcopy a nested dict."""
+    if not isinstance(nested_dict, Dict):
+        return nested_dict
+    return {key: value for key, value in nested_dict.items()}
+
+
 class InputFormat(LightningEnum):
     """The ``InputFormat`` enum contains the data source names used by all of the default ``from_*`` methods in
     :class:`~flash.core.data.data_module.DataModule`."""
@@ -166,48 +168,28 @@ class InputBase(Properties, metaclass=_InputMeta):
         **kwargs: Any additional keyword arguments to pass to the ``load_data`` hook.
     """
 
-    input_transforms_registry = FlashRegistry("input_transforms")
+    def __init__(self, running_stage: RunningStage, *args: Any, **kwargs: Any) -> None:
 
-    def __init__(
-        self,
-        running_stage: RunningStage,
-        *args: Any,
-        transform: INPUT_TRANSFORM_TYPE = None,
-        transform_kwargs: Optional[Dict] = None,
-        input_transforms_registry: Optional[FlashRegistry] = None,
-        **kwargs: Any,
-    ) -> None:
-        from flash.core.data.io.input_transform import create_transform
-
-        self.transform = create_transform(
-            transform,
-            running_stage,
-            input_transforms_registry or self.input_transforms_registry,
-            transform_kwargs,
-        )
         super().__init__(running_stage=running_stage)
 
         self.data = None
         if len(args) >= 1 and args[0] is not None:
             self.data = getattr(self, f"{_STAGES_PREFIX[running_stage]}_load_data")(*args, **kwargs)
 
-    def _create_dataloader_collate_fn(self, callbacks: List[FlashCallback]) -> Optional[Callable]:
-        from flash.core.data.io.input_transform import _create_collate_input_transform_processors
-
-        if not self.transform:
-            return
-        return _create_collate_input_transform_processors(self.transform, callbacks)[0]
-
-    def _create_on_after_batch_transfer_fn(self, callbacks: List[FlashCallback]) -> Optional[Callable]:
-        from flash.core.data.io.input_transform import _create_collate_input_transform_processors
-
-        if not self.transform:
-            return
-        return _create_collate_input_transform_processors(self.transform, callbacks)[1]
-
     def _call_load_sample(self, sample: Any) -> Any:
         # Deepcopy the sample to avoid leaks with complex data structures
-        return getattr(self, f"{_STAGES_PREFIX[self.running_stage]}_load_sample")(deepcopy(sample))
+        sample_output = getattr(self, f"{_STAGES_PREFIX[self.running_stage]}_load_sample")(_deepcopy_dict(sample))
+
+        # Change DataKeys Enum to strings
+        if isinstance(sample_output, dict):
+            output_dict = {}
+            for key, val in sample_output.items():
+                if isinstance(key, Enum) and hasattr(key, "value"):
+                    output_dict[key.value] = val
+                else:
+                    output_dict[key] = val
+            return output_dict
+        return sample_output
 
     @staticmethod
     def load_data(*args: Any, **kwargs: Any) -> Union[Sequence, Iterable]:
@@ -307,16 +289,6 @@ class InputBase(Properties, metaclass=_InputMeta):
         """
         return self.data is not None
 
-    @classmethod
-    def register_input_transform(
-        cls, enum: Union[LightningEnum, str], fn: Union[Type["flash.InputTransform"], partial]
-    ) -> None:
-        if cls.input_transforms_registry is None:
-            raise MisconfigurationException(
-                "The class attribute `input_transforms_registry` should be set as a class attribute. "
-            )
-        cls.input_transforms_registry(fn=fn, name=enum)
-
 
 class Input(InputBase, Dataset):
     def __getitem__(self, index: int) -> Any:
@@ -336,26 +308,15 @@ class IterableInput(InputBase, IterableDataset, metaclass=_IterableInputMeta):
 
 
 class ServeInput(Input):
-    def __init__(
-        self,
-        transform: INPUT_TRANSFORM_TYPE = None,
-        transform_kwargs: Optional[Dict] = None,
-    ) -> None:
+    def __init__(self) -> None:
         if hasattr(self, "serve_load_data"):
             raise MisconfigurationException("`serve_load_data` shouldn't be implemented.")
 
-        super().__init__(
-            RunningStage.SERVING,
-            transform=transform,
-            transform_kwargs=transform_kwargs,
-        )
+        super().__init__(RunningStage.SERVING)
 
     def serve_load_sample(self, sample: Any) -> List[Any]:
         raise NotImplementedError
 
-    def __call__(self, sample: Any) -> Any:
-        return self._call_load_sample(sample)
-
     def example_input(self) -> str:
         raise NotImplementedError
 
