@@ -15,7 +15,6 @@ import inspect
 import re
 from abc import ABCMeta
 from copy import deepcopy
-from importlib import import_module
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
 import pytorch_lightning as pl
@@ -26,17 +25,22 @@ from pytorch_lightning.callbacks import Callback
 from pytorch_lightning.callbacks.finetuning import BaseFinetuning
 from pytorch_lightning.utilities.enums import LightningEnum
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from torch import nn
+from torch import nn, Tensor
 from torch.optim.lr_scheduler import _LRScheduler
 from torch.optim.optimizer import Optimizer
 from torch.utils.data import DataLoader, Sampler
 
 import flash
 from flash.core.data.io.input import InputBase, ServeInput
-from flash.core.data.io.input_transform import InputTransform
+from flash.core.data.io.input_transform import (
+    create_or_configure_input_transform,
+    create_worker_input_transform_processor,
+    InputTransform,
+)
 from flash.core.data.io.output import Output
 from flash.core.data.io.output_transform import OutputTransform
 from flash.core.data.output import BASE_OUTPUTS
+from flash.core.data.utilities.collate import default_collate
 from flash.core.finetuning import _FINETUNING_STRATEGIES_REGISTRY
 from flash.core.hooks import FineTuningHooks
 from flash.core.optimizers.optimizers import _OPTIMIZERS_REGISTRY
@@ -44,8 +48,9 @@ from flash.core.optimizers.schedulers import _SCHEDULERS_REGISTRY
 from flash.core.registry import FlashRegistry
 from flash.core.serve.composition import Composition
 from flash.core.utilities.apply_func import get_callable_dict
-from flash.core.utilities.imports import _PL_GREATER_EQUAL_1_5_0, requires
+from flash.core.utilities.imports import _CORE_TESTING, _PL_GREATER_EQUAL_1_5_0, requires
 from flash.core.utilities.providers import _HUGGINGFACE
+from flash.core.utilities.stages import RunningStage
 from flash.core.utilities.types import (
     INPUT_TRANSFORM_TYPE,
     LOSS_FN_TYPE,
@@ -56,6 +61,10 @@ from flash.core.utilities.types import (
     OUTPUT_TRANSFORM_TYPE,
 )
 
+# Skip doctests if requirements aren't available
+if not _CORE_TESTING:
+    __doctest_skip__ = ["Task", "Task.*"]
+
 
 class ModuleWrapperBase:
     """The ``ModuleWrapperBase`` is a base for classes which wrap a ``LightningModule`` or an instance of
@@ -90,12 +99,12 @@ class DatasetProcessor:
     def __init__(self):
         super().__init__()
 
-        self._collate_fn = None
+        self._collate_fn = default_collate
         self._input_transform = None
 
     @torch.jit.unused
     @property
-    def collate_fn(self) -> Optional[Callable]:
+    def collate_fn(self) -> Callable:
         return self._collate_fn
 
     @collate_fn.setter
@@ -104,25 +113,37 @@ class DatasetProcessor:
 
     @torch.jit.unused
     @property
-    def input_transform(self) -> Optional[INPUT_TRANSFORM_TYPE]:
-        return self._input_transform
+    def input_transform(self) -> Optional[InputTransform]:
+        if self._input_transform is not None:
+            return create_or_configure_input_transform(self._input_transform)
+        return None
 
     @input_transform.setter
-    def input_transform(self, input_transform: INPUT_TRANSFORM_TYPE) -> None:
+    def input_transform(self, input_transform: InputTransform) -> None:
         self._input_transform = input_transform
 
-    def _process_dataset(
+    def process_train_dataset(
         self,
         dataset: InputBase,
         batch_size: int,
-        num_workers: int,
-        pin_memory: bool,
-        collate_fn: Callable,
-        shuffle: bool = False,
+        num_workers: int = 0,
+        pin_memory: bool = False,
+        shuffle: bool = True,
         drop_last: bool = True,
         sampler: Optional[Sampler] = None,
         persistent_workers: bool = False,
+        input_transform: Optional[InputTransform] = None,
+        trainer: Optional["flash.Trainer"] = None,
     ) -> DataLoader:
+        input_transform = input_transform or self.input_transform
+
+        collate_fn = self.collate_fn
+        if input_transform is not None:
+            # Inject the `self.collate_fn`
+            input_transform.inject_collate_fn(self.collate_fn)
+
+            collate_fn = create_worker_input_transform_processor(RunningStage.TRAINING, input_transform)
+
         return DataLoader(
             dataset,
             batch_size=batch_size,
@@ -131,106 +152,109 @@ class DatasetProcessor:
             shuffle=shuffle,
             drop_last=drop_last,
             sampler=sampler,
-            collate_fn=self.collate_fn if self.collate_fn is not None else collate_fn,
-            persistent_workers=persistent_workers,
-        )
-
-    def process_train_dataset(
-        self,
-        dataset: InputBase,
-        trainer: "flash.Trainer",
-        batch_size: int,
-        num_workers: int,
-        pin_memory: bool,
-        collate_fn: Callable,
-        shuffle: bool = False,
-        drop_last: bool = True,
-        sampler: Optional[Sampler] = None,
-        persistent_workers: bool = False,
-    ) -> DataLoader:
-        return self._process_dataset(
-            dataset,
-            batch_size=batch_size,
-            num_workers=num_workers,
-            pin_memory=pin_memory,
-            collate_fn=self.collate_fn if self.collate_fn is not None else collate_fn,
-            shuffle=shuffle,
-            drop_last=drop_last,
-            sampler=sampler,
+            collate_fn=collate_fn,
             persistent_workers=persistent_workers,
         )
 
     def process_val_dataset(
         self,
         dataset: InputBase,
-        trainer: "flash.Trainer",
         batch_size: int,
-        num_workers: int,
-        pin_memory: bool,
-        collate_fn: Callable,
+        num_workers: int = 0,
+        pin_memory: bool = False,
         shuffle: bool = False,
         drop_last: bool = False,
         sampler: Optional[Sampler] = None,
         persistent_workers: bool = False,
+        input_transform: Optional[InputTransform] = None,
+        trainer: Optional["flash.Trainer"] = None,
     ) -> DataLoader:
-        return self._process_dataset(
+        input_transform = input_transform or self.input_transform
+
+        collate_fn = self.collate_fn
+        if input_transform is not None:
+            # Inject the `self.collate_fn`
+            input_transform.inject_collate_fn(self.collate_fn)
+
+            collate_fn = create_worker_input_transform_processor(RunningStage.VALIDATING, input_transform)
+
+        return DataLoader(
             dataset,
             batch_size=batch_size,
             num_workers=num_workers,
             pin_memory=pin_memory,
-            collate_fn=self.collate_fn if self.collate_fn is not None else collate_fn,
             shuffle=shuffle,
             drop_last=drop_last,
             sampler=sampler,
+            collate_fn=collate_fn,
             persistent_workers=persistent_workers,
         )
 
     def process_test_dataset(
         self,
         dataset: InputBase,
-        trainer: "flash.Trainer",
         batch_size: int,
-        num_workers: int,
-        pin_memory: bool,
-        collate_fn: Callable,
+        num_workers: int = 0,
+        pin_memory: bool = False,
         shuffle: bool = False,
         drop_last: bool = False,
         sampler: Optional[Sampler] = None,
         persistent_workers: bool = False,
+        input_transform: Optional[InputTransform] = None,
+        trainer: Optional["flash.Trainer"] = None,
     ) -> DataLoader:
-        return self._process_dataset(
+        input_transform = input_transform or self.input_transform
+
+        collate_fn = self.collate_fn
+        if input_transform is not None:
+            # Inject the `self.collate_fn`
+            input_transform.inject_collate_fn(self.collate_fn)
+
+            collate_fn = create_worker_input_transform_processor(RunningStage.TESTING, input_transform)
+
+        return DataLoader(
             dataset,
             batch_size=batch_size,
             num_workers=num_workers,
             pin_memory=pin_memory,
-            collate_fn=self.collate_fn if self.collate_fn is not None else collate_fn,
             shuffle=shuffle,
             drop_last=drop_last,
             sampler=sampler,
+            collate_fn=collate_fn,
             persistent_workers=persistent_workers,
         )
 
     def process_predict_dataset(
         self,
         dataset: InputBase,
-        batch_size: int = 1,
+        batch_size: int,
         num_workers: int = 0,
         pin_memory: bool = False,
-        collate_fn: Callable = None,
         shuffle: bool = False,
         drop_last: bool = False,
         sampler: Optional[Sampler] = None,
         persistent_workers: bool = False,
+        input_transform: Optional[InputTransform] = None,
+        trainer: Optional["flash.Trainer"] = None,
     ) -> DataLoader:
-        return self._process_dataset(
+        input_transform = input_transform or self.input_transform
+
+        collate_fn = self.collate_fn
+        if input_transform is not None:
+            # Inject the `self.collate_fn`
+            input_transform.inject_collate_fn(self.collate_fn)
+
+            collate_fn = create_worker_input_transform_processor(RunningStage.PREDICTING, input_transform)
+
+        return DataLoader(
             dataset,
             batch_size=batch_size,
             num_workers=num_workers,
             pin_memory=pin_memory,
-            collate_fn=self.collate_fn if self.collate_fn is not None else collate_fn,
             shuffle=shuffle,
             drop_last=drop_last,
             sampler=sampler,
+            collate_fn=collate_fn,
             persistent_workers=persistent_workers,
         )
 
@@ -255,12 +279,19 @@ class CheckDependenciesMeta(ABCMeta):
     def __new__(mcs, *args, **kwargs):
         result = ABCMeta.__new__(mcs, *args, **kwargs)
         if result.required_extras is not None:
-            result.__init__ = requires(result.required_extras)(result.__init__)
+            if isinstance(result.required_extras, str):
+                result.required_extras = [result.required_extras]
+            result.__init__ = requires(*result.required_extras)(result.__init__)
 
             patterns = ["load_from_checkpoint", "available_*"]  # must match classmethods only
             regex = "(" + ")|(".join(patterns) + ")"
             for attribute_name, attribute_value in filter(lambda x: re.match(regex, x[0]), inspect.getmembers(result)):
-                setattr(result, attribute_name, classmethod(requires(result.required_extras)(attribute_value.__func__)))
+                # TODO: Find a better way to do this
+                if attribute_name in ["available_layers"]:
+                    continue
+                setattr(
+                    result, attribute_name, classmethod(requires(*result.required_extras)(attribute_value.__func__))
+                )
         return result
 
 
@@ -296,8 +327,8 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
             task.
     """
 
-    optimizers: FlashRegistry = _OPTIMIZERS_REGISTRY
-    lr_schedulers: FlashRegistry = _SCHEDULERS_REGISTRY
+    optimizers_registry: FlashRegistry = _OPTIMIZERS_REGISTRY
+    lr_schedulers_registry: FlashRegistry = _SCHEDULERS_REGISTRY
     finetuning_strategies: FlashRegistry = _FINETUNING_STRATEGIES_REGISTRY
     outputs: FlashRegistry = BASE_OUTPUTS
 
@@ -375,27 +406,27 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
         output[OutputKeys.LOSS] = self.compute_loss(losses)
         output[OutputKeys.LOGS] = self.compute_logs(logs, losses)
         output[OutputKeys.TARGET] = y
-        output[OutputKeys.BATCH_SIZE] = y.shape[0] if isinstance(y, torch.Tensor) else None
+        output[OutputKeys.BATCH_SIZE] = y.shape[0] if isinstance(y, Tensor) else None
         return output
 
-    def compute_loss(self, losses: Dict[str, torch.Tensor]) -> torch.Tensor:
+    def compute_loss(self, losses: Dict[str, Tensor]) -> Tensor:
         return list(losses.values())[0]
 
-    def compute_logs(self, logs: Dict[str, Any], losses: Dict[str, torch.Tensor]):
+    def compute_logs(self, logs: Dict[str, Any], losses: Dict[str, Tensor]):
         logs.update(losses)
         return logs
 
     @staticmethod
-    def apply_filtering(y: torch.Tensor, y_hat: torch.Tensor) -> Tuple[torch.Tensor, torch.Tensor]:
+    def apply_filtering(y: Tensor, y_hat: Tensor) -> Tuple[Tensor, Tensor]:
         """This function is used to filter some labels or predictions which aren't conform."""
         return y, y_hat
 
     @staticmethod
-    def to_loss_format(x: torch.Tensor) -> torch.Tensor:
+    def to_loss_format(x: Tensor) -> Tensor:
         return x
 
     @staticmethod
-    def to_metrics_format(x: torch.Tensor) -> torch.Tensor:
+    def to_metrics_format(x: Tensor) -> Tensor:
         return x
 
     def forward(self, x: Any) -> Any:
@@ -446,7 +477,7 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
             batch = torch.stack(batch)
         return self(batch)
 
-    def modules_to_freeze(self) -> Optional[Union[nn.Module]]:
+    def modules_to_freeze(self) -> Optional[nn.Module]:
         """By default, we try to get the ``backbone`` attribute from the task and return it or ``None`` if not
         present.
 
@@ -462,7 +493,7 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
                 f"\nUse `{self.__class__.__name__}.available_optimizers()` to list the available optimizers."
                 f"\nList of available Optimizers: {self.available_optimizers()}."
             )
-        optimizer_fn = self.optimizers.get(optimizer_key.lower())
+        optimizer_fn = self.optimizers_registry.get(optimizer_key.lower())
         return optimizer_fn
 
     def configure_optimizers(self) -> Union[Optimizer, Tuple[List[Optimizer], List[_LRScheduler]]]:
@@ -542,6 +573,25 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
 
         return [finetuning_strategy_fn(**finetuning_strategy_metadata)]
 
+    def as_embedder(self, layer: str):
+        """Convert this task to an embedder. Note that the parameters are not copied so that any optimization of
+        the embedder will also apply to the converted ``Task``.
+
+        Args:
+            layer: The layer to embed to. This should be one of the :meth:`~flash.core.model.Task.available_layers`.
+        """
+        from flash.core.utilities.embedder import Embedder  # Avoid circular import
+
+        return Embedder(self, layer)
+
+    def available_layers(self):
+        """Get the list of available layers for use with the :meth:`~flash.core.model.Task.as_embedder` method."""
+        available_layers = []
+        for name, _ in self.named_modules():
+            if name not in ["train_metrics", "val_metrics", "test_metrics"]:
+                available_layers.append(name)
+        return ["output"] + available_layers
+
     @classmethod
     def available_backbones(
         cls, head: Optional[str] = None
@@ -586,7 +636,7 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
     @classmethod
     def available_optimizers(cls) -> List[str]:
         """Returns a list containing the keys of the available Optimizers."""
-        registry: Optional[FlashRegistry] = getattr(cls, "optimizers", None)
+        registry: Optional[FlashRegistry] = getattr(cls, "optimizers_registry", None)
         if registry is None:
             return []
         return registry.available_keys()
@@ -594,7 +644,7 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
     @classmethod
     def available_lr_schedulers(cls) -> List[str]:
         """Returns a list containing the keys of the available LR schedulers."""
-        registry: Optional[FlashRegistry] = getattr(cls, "lr_schedulers", None)
+        registry: Optional[FlashRegistry] = getattr(cls, "lr_schedulers_registry", None)
         if registry is None:
             return []
         return registry.available_keys()
@@ -655,7 +705,7 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
                 f"\nUse `{self.__class__.__name__}.available_lr_schedulers()` to list the available schedulers."
                 f"\n>>> List of available LR Schedulers: {self.available_lr_schedulers()}."
             )
-        lr_scheduler_fn: Dict[str, Any] = self.lr_schedulers.get(lr_scheduler_key.lower(), with_metadata=True)
+        lr_scheduler_fn: Dict[str, Any] = self.lr_schedulers_registry.get(lr_scheduler_key.lower(), with_metadata=True)
         return deepcopy(lr_scheduler_fn)
 
     def _instantiate_lr_scheduler(self, optimizer: Optimizer) -> Dict[str, Any]:
@@ -764,45 +814,21 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
         lr_scheduler_config["scheduler"] = lr_scheduler
         return lr_scheduler_config
 
-    def _load_from_state_dict(
-        self, state_dict, prefix, local_metadata, strict, missing_keys, unexpected_keys, error_msgs
-    ):
-        if "input_transform.state_dict" in state_dict:
-            try:
-                input_transform_state_dict = state_dict["input_transform.state_dict"]
-                meta = input_transform_state_dict["_meta"]
-                cls = getattr(import_module(meta["module"]), meta["class_name"])
-                self._input_transform = cls.load_state_dict(
-                    {k: v for k, v in input_transform_state_dict.items() if k != "_meta"},
-                    strict=strict,
-                )
-                self._input_transform._state = meta["_state"]
-                del state_dict["input_transform.state_dict"]
-                del input_transform_state_dict["_meta"]
-            except (ModuleNotFoundError, KeyError):
-                meta = state_dict["input_transform.state_dict"]["_meta"]
-                raise MisconfigurationException(
-                    f"The `InputTransform` {meta['module']}.{meta['class_name']}"
-                    "has been moved and couldn't be imported."
-                )
-
-        super()._load_from_state_dict(
-            state_dict, prefix, local_metadata, strict, missing_keys, unexpected_keys, error_msgs
-        )
-
     def configure_callbacks(self):
         # used only for CI
         if flash._IS_TESTING and torch.cuda.is_available():
             return [BenchmarkConvergenceCI()]
 
     @requires("serve")
-    def run_serve_sanity_check(self, serve_input: ServeInput, output: Output):
+    def run_serve_sanity_check(
+        self, serve_input: ServeInput, transform: INPUT_TRANSFORM_TYPE, transform_kwargs: Optional[Dict], output: Output
+    ):
         from fastapi.testclient import TestClient
 
         from flash.core.serve.flash_components import build_flash_serve_model_component
 
         print("Running serve sanity check")
-        comp = build_flash_serve_model_component(self, serve_input, output)
+        comp = build_flash_serve_model_component(self, serve_input, output, transform, transform_kwargs)
         composition = Composition(predict=comp, TESTING=True, DEBUG=True)
         app = composition.serve(host="0.0.0.0", port=8000)
 
@@ -839,16 +865,16 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks
         if input_cls is None:
             raise NotImplementedError("The `input_cls` must be provided to enable serving.")
 
-        serve_input = input_cls(transform=transform, transform_kwargs=transform_kwargs)
+        serve_input = input_cls()
 
         output = output or Output()
         if isinstance(output, str):
             output = self.outputs.get(output).from_task(self)
 
         if sanity_check:
-            self.run_serve_sanity_check(serve_input, output)
+            self.run_serve_sanity_check(serve_input, transform, transform_kwargs, output)
 
-        comp = build_flash_serve_model_component(self, serve_input, output)
+        comp = build_flash_serve_model_component(self, serve_input, output, transform, transform_kwargs)
         composition = Composition(predict=comp, TESTING=flash._IS_TESTING)
         composition.serve(host=host, port=port)
         return composition
