@@ -2,6 +2,7 @@ from dataclasses import dataclass
 from typing import Union
 
 import torch
+from torch import Tensor
 
 from flash.core.serve.types.base import BaseType
 
@@ -10,8 +11,8 @@ from flash.core.serve.types.base import BaseType
 class Number(BaseType):
     """A datatype representing a single item tensor (an int/float number)"""
 
-    def deserialize(self, num: Union[float, int]) -> torch.Tensor:
+    def deserialize(self, num: Union[float, int]) -> Tensor:
         return torch.as_tensor(num).view((1, 1))
 
-    def serialize(self, data: torch.Tensor) -> Union[float, int]:
+    def serialize(self, data: Tensor) -> Union[float, int]:
         return data.item()
