@@ -42,13 +42,10 @@ class GraphClassificationData(DataModule):
         val_dataset: Optional[Dataset] = None,
         test_dataset: Optional[Dataset] = None,
         predict_dataset: Optional[Dataset] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = GraphClassificationInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = GraphClassificationInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = GraphClassificationInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = GraphClassificationInputTransform,
-        target_formatter: Optional[TargetFormatter] = None,
         input_cls: Type[Input] = GraphClassificationDatasetInput,
+        transform: INPUT_TRANSFORM_TYPE = GraphClassificationInputTransform,
         transform_kwargs: Optional[Dict] = None,
+        target_formatter: Optional[TargetFormatter] = None,
         **data_module_kwargs,
     ) -> "GraphClassificationData":
         """Load the :class:`~flash.graph.classification.data.GraphClassificationData` from PyTorch Dataset objects.
@@ -67,14 +64,10 @@ class GraphClassificationData(DataModule):
             val_dataset: The Dataset to use when validating.
             test_dataset: The Dataset to use when testing.
             predict_dataset: The Dataset to use when predicting.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-                predicting.
             target_formatter: Optionally provide a :class:`~flash.core.data.utilities.classification.TargetFormatter` to
                 control how targets are handled. If ``None`` then no formatting will be applied to targets.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
                 :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -175,18 +168,18 @@ class GraphClassificationData(DataModule):
 
         ds_kw = dict(
             target_formatter=target_formatter,
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
         )
 
-        train_input = input_cls(RunningStage.TRAINING, train_dataset, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, train_dataset, **ds_kw)
         ds_kw["target_formatter"] = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(RunningStage.VALIDATING, val_dataset, transform=val_transform, **ds_kw),
-            input_cls(RunningStage.TESTING, test_dataset, transform=test_transform, **ds_kw),
-            input_cls(RunningStage.PREDICTING, predict_dataset, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, val_dataset, **ds_kw),
+            input_cls(RunningStage.TESTING, test_dataset, **ds_kw),
+            input_cls(RunningStage.PREDICTING, predict_dataset, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
