@@ -24,16 +24,19 @@ from pytorch_lightning.plugins import DataParallelPlugin, DDPPlugin, DDPSpawnPlu
 from pytorch_lightning.trainer.states import TrainerFn
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from pytorch_lightning.utilities.warnings import WarningCache
+from torch import nn, Tensor
 from torch.utils.data import DataLoader, IterableDataset, Sampler
 
 import flash
 from flash.core.adapter import Adapter, AdapterTask
 from flash.core.data.io.input import DataKeys, InputBase
+from flash.core.data.io.input_transform import InputTransform
 from flash.core.model import Task
 from flash.core.registry import FlashRegistry
 from flash.core.utilities.compatibility import accelerator_connector
 from flash.core.utilities.imports import _LEARN2LEARN_AVAILABLE
 from flash.core.utilities.providers import _LEARN2LEARN
+from flash.core.utilities.stability import beta
 from flash.core.utilities.url_error import catch_url_error
 from flash.image.classification.integrations.learn2learn import TaskDataParallel, TaskDistributedDataParallel
 
@@ -56,8 +59,8 @@ class RemapLabels(Learn2LearnRemapLabels):
         return data
 
 
-class Model(torch.nn.Module):
-    def __init__(self, backbone: torch.nn.Module, head: Optional[torch.nn.Module]):
+class Model(nn.Module):
+    def __init__(self, backbone: nn.Module, head: Optional[nn.Module]):
         super().__init__()
         self.backbone = backbone
         self.head = head
@@ -71,14 +74,15 @@ class Model(torch.nn.Module):
         return self.head(x)
 
 
+@beta("The Learn2Learn integration is currently in Beta.")
 class Learn2LearnAdapter(Adapter):
 
     required_extras: str = "image"
 
     def __init__(
         self,
-        backbone: torch.nn.Module,
-        head: torch.nn.Module,
+        backbone: nn.Module,
+        head: nn.Module,
         algorithm_cls: Type[LightningModule],
         ways: int,
         shots: int,
@@ -203,6 +207,11 @@ class Learn2LearnAdapter(Adapter):
         num_task: int,
         epoch_length: int,
     ):
+        if trainer is None:
+            raise MisconfigurationException(
+                "The Learn2Learn integration requires the `Trainer` to be passed to the `process_*_dataset` method."
+            )
+
         if isinstance(dataset, InputBase):
 
             metadata = getattr(dataset, "data", None)
@@ -272,8 +281,8 @@ class Learn2LearnAdapter(Adapter):
         cls,
         *args,
         task: AdapterTask,
-        backbone: torch.nn.Module,
-        head: torch.nn.Module,
+        backbone: nn.Module,
+        head: nn.Module,
         algorithm: Type[LightningModule],
         **kwargs,
     ) -> Adapter:
@@ -324,15 +333,15 @@ class Learn2LearnAdapter(Adapter):
     def process_train_dataset(
         self,
         dataset: InputBase,
-        trainer: "flash.Trainer",
         batch_size: int,
-        num_workers: int,
-        pin_memory: bool,
-        collate_fn: Callable,
-        shuffle: bool = False,
-        drop_last: bool = False,
+        num_workers: int = 0,
+        pin_memory: bool = False,
+        shuffle: bool = True,
+        drop_last: bool = True,
         sampler: Optional[Sampler] = None,
         persistent_workers: bool = False,
+        input_transform: Optional[InputTransform] = None,
+        trainer: Optional["flash.Trainer"] = None,
     ) -> DataLoader:
         dataset = self._convert_dataset(
             trainer=trainer,
@@ -349,29 +358,29 @@ class Learn2LearnAdapter(Adapter):
             sampler = None
         return super().process_train_dataset(
             dataset,
-            trainer,
             self._sanetize_batch_size(batch_size),
-            num_workers,
-            False,
-            collate_fn,
+            num_workers=num_workers,
+            pin_memory=False,
             shuffle=shuffle,
             drop_last=drop_last,
             sampler=sampler,
             persistent_workers=persistent_workers,
+            input_transform=input_transform,
+            trainer=trainer,
         )
 
     def process_val_dataset(
         self,
         dataset: InputBase,
-        trainer: "flash.Trainer",
         batch_size: int,
-        num_workers: int,
-        pin_memory: bool,
-        collate_fn: Callable,
+        num_workers: int = 0,
+        pin_memory: bool = False,
         shuffle: bool = False,
         drop_last: bool = False,
         sampler: Optional[Sampler] = None,
         persistent_workers: bool = False,
+        input_transform: Optional[InputTransform] = None,
+        trainer: Optional["flash.Trainer"] = None,
     ) -> DataLoader:
         dataset = self._convert_dataset(
             trainer=trainer,
@@ -386,31 +395,31 @@ class Learn2LearnAdapter(Adapter):
         if isinstance(dataset, IterableDataset):
             shuffle = False
             sampler = None
-        return super().process_train_dataset(
+        return super().process_val_dataset(
             dataset,
-            trainer,
             self._sanetize_batch_size(batch_size),
-            num_workers,
-            False,
-            collate_fn,
+            num_workers=num_workers,
+            pin_memory=False,
             shuffle=shuffle,
             drop_last=drop_last,
             sampler=sampler,
             persistent_workers=persistent_workers,
+            input_transform=input_transform,
+            trainer=trainer,
         )
 
     def process_test_dataset(
         self,
         dataset: InputBase,
-        trainer: "flash.Trainer",
         batch_size: int,
-        num_workers: int,
-        pin_memory: bool,
-        collate_fn: Callable,
+        num_workers: int = 0,
+        pin_memory: bool = False,
         shuffle: bool = False,
         drop_last: bool = False,
         sampler: Optional[Sampler] = None,
         persistent_workers: bool = False,
+        input_transform: Optional[InputTransform] = None,
+        trainer: Optional["flash.Trainer"] = None,
     ) -> DataLoader:
         dataset = self._convert_dataset(
             trainer=trainer,
@@ -425,30 +434,31 @@ class Learn2LearnAdapter(Adapter):
         if isinstance(dataset, IterableDataset):
             shuffle = False
             sampler = None
-        return super().process_train_dataset(
+        return super().process_test_dataset(
             dataset,
-            trainer,
             self._sanetize_batch_size(batch_size),
-            num_workers,
-            False,
-            collate_fn,
+            num_workers=num_workers,
+            pin_memory=False,
             shuffle=shuffle,
             drop_last=drop_last,
             sampler=sampler,
             persistent_workers=persistent_workers,
+            input_transform=input_transform,
+            trainer=trainer,
         )
 
     def process_predict_dataset(
         self,
         dataset: InputBase,
-        batch_size: int = 1,
+        batch_size: int,
         num_workers: int = 0,
         pin_memory: bool = False,
-        collate_fn: Callable = lambda x: x,
         shuffle: bool = False,
-        drop_last: bool = True,
+        drop_last: bool = False,
         sampler: Optional[Sampler] = None,
         persistent_workers: bool = False,
+        input_transform: Optional[InputTransform] = None,
+        trainer: Optional["flash.Trainer"] = None,
     ) -> DataLoader:
 
         if not self._algorithm_has_validated:
@@ -459,13 +469,13 @@ class Learn2LearnAdapter(Adapter):
         return super().process_predict_dataset(
             dataset,
             batch_size,
-            num_workers,
-            pin_memory,
-            collate_fn,
+            num_workers=num_workers,
+            pin_memory=pin_memory,
             shuffle=shuffle,
             drop_last=drop_last,
             sampler=sampler,
             persistent_workers=persistent_workers,
+            input_transform=input_transform,
         )
 
 
@@ -474,7 +484,7 @@ class DefaultAdapter(Adapter):
 
     required_extras: str = "image"
 
-    def __init__(self, backbone: torch.nn.Module, head: torch.nn.Module):
+    def __init__(self, backbone: nn.Module, head: nn.Module):
         super().__init__()
 
         self.backbone = backbone
@@ -486,8 +496,8 @@ class DefaultAdapter(Adapter):
         cls,
         *args,
         task: AdapterTask,
-        backbone: torch.nn.Module,
-        head: torch.nn.Module,
+        backbone: nn.Module,
+        head: nn.Module,
         **kwargs,
     ) -> Adapter:
         adapter = cls(backbone, head)
@@ -512,7 +522,7 @@ class DefaultAdapter(Adapter):
         )
         return batch
 
-    def forward(self, x) -> torch.Tensor:
+    def forward(self, x) -> Tensor:
         # TODO: Resolve this hack
         if x.dim() == 3:
             x = x.unsqueeze(0)
