@@ -14,13 +14,10 @@
 from functools import partial
 from typing import Optional
 
-import torch
-
 from flash.core.adapter import Adapter
 from flash.core.integrations.icevision.adapter import IceVisionAdapter, SimpleCOCOMetric
 from flash.core.integrations.icevision.backbones import (
     get_backbones,
-    icevision_model_adapter,
     load_icevision_ignore_image_size,
     load_icevision_with_image_size,
 )
@@ -33,6 +30,11 @@ if _ICEVISION_AVAILABLE:
     from icevision import models as icevision_models
     from icevision.metrics import COCOMetricType
     from icevision.metrics import Metric as IceVisionMetric
+else:
+
+    class COCOMetricType:
+        bbox = None
+
 
 OBJECT_DETECTION_HEADS = FlashRegistry("heads")
 
@@ -46,7 +48,7 @@ class IceVisionObjectDetectionAdapter(IceVisionAdapter):
         backbone: str = "resnet18_fpn",
         head: str = "retinanet",
         pretrained: bool = True,
-        metrics: Optional["IceVisionMetric"] = None,
+        metrics: Optional["IceVisionMetric"] = SimpleCOCOMetric(COCOMetricType.bbox),
         image_size: Optional = None,
         **kwargs,
     ) -> Adapter:
@@ -56,7 +58,7 @@ class IceVisionObjectDetectionAdapter(IceVisionAdapter):
             backbone=backbone,
             head=head,
             pretrained=pretrained,
-            metrics=metrics or [SimpleCOCOMetric(COCOMetricType.bbox)],
+            metrics=metrics,
             image_size=image_size,
             **kwargs,
         )
@@ -66,7 +68,7 @@ if _ICEVISION_AVAILABLE:
     if _TORCHVISION_AVAILABLE:
         for model_type in [icevision_models.torchvision.retinanet, icevision_models.torchvision.faster_rcnn]:
             OBJECT_DETECTION_HEADS(
-                partial(load_icevision_ignore_image_size, icevision_model_adapter, model_type),
+                partial(load_icevision_ignore_image_size, model_type),
                 model_type.__name__.split(".")[-1],
                 backbones=get_backbones(model_type),
                 adapter=IceVisionObjectDetectionAdapter,
@@ -76,7 +78,7 @@ if _ICEVISION_AVAILABLE:
     if _module_available("yolov5"):
         model_type = icevision_models.ultralytics.yolov5
         OBJECT_DETECTION_HEADS(
-            partial(load_icevision_with_image_size, icevision_model_adapter, model_type),
+            partial(load_icevision_with_image_size, model_type),
             model_type.__name__.split(".")[-1],
             backbones=get_backbones(model_type),
             adapter=IceVisionObjectDetectionAdapter,
@@ -91,7 +93,7 @@ if _ICEVISION_AVAILABLE:
             icevision_models.mmdet.sparse_rcnn,
         ]:
             OBJECT_DETECTION_HEADS(
-                partial(load_icevision_ignore_image_size, icevision_model_adapter, model_type),
+                partial(load_icevision_ignore_image_size, model_type),
                 f"mmdet_{model_type.__name__.split('.')[-1]}",
                 backbones=get_backbones(model_type),
                 adapter=IceVisionObjectDetectionAdapter,
@@ -100,24 +102,9 @@ if _ICEVISION_AVAILABLE:
 
     if _module_available("effdet"):
 
-        def _icevision_effdet_validation_step(self, batch, batch_idx):
-            images = batch[0][0]
-            batch[0][1]["img_scale"] = torch.ones_like(images[:, 0, 0, 0]).unsqueeze(1)
-            batch[0][1]["img_size"] = (
-                (torch.ones_like(images[:, 0, 0, 0]) * images[0].shape[-1]).unsqueeze(1).repeat(1, 2)
-            )
-            return self._original_validation_step(batch, batch_idx)
-
-        def _icevision_effdet_model_adapter(model_type):
-            adapter = icevision_model_adapter(model_type)
-            if not hasattr(adapter, "_original_validation_step"):
-                adapter._original_validation_step = adapter.validation_step
-                adapter.validation_step = _icevision_effdet_validation_step
-            return adapter
-
         model_type = icevision_models.ross.efficientdet
         OBJECT_DETECTION_HEADS(
-            partial(load_icevision_with_image_size, _icevision_effdet_model_adapter, model_type),
+            partial(load_icevision_with_image_size, model_type),
             model_type.__name__.split(".")[-1],
             backbones=get_backbones(model_type),
             adapter=IceVisionObjectDetectionAdapter,
