@@ -18,7 +18,6 @@ import numpy as np
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 
 from flash.core.data.io.input import DataKeys, Input, ServeInput
-from flash.core.data.utilities.data_frame import read_csv
 from flash.core.utilities.imports import _PANDAS_AVAILABLE
 from flash.tabular.classification.utils import (
     _compute_normalization,
@@ -29,6 +28,7 @@ from flash.tabular.classification.utils import (
 )
 
 if _PANDAS_AVAILABLE:
+    import pandas as pd
     from pandas.core.frame import DataFrame
 else:
     DataFrame = object
@@ -121,7 +121,7 @@ class TabularDeserializer(ServeInput):
     def serve_load_sample(self, data: str) -> Any:
         parameters = self._parameters
 
-        df = read_csv(StringIO(data))
+        df = pd.read_csv(StringIO(data))
         df = _pre_transform(
             df,
             parameters["numerical_fields"],
